import React, { useState } from "react";
import Book from "./Book";
import { data } from "./data.js";
import MenuTitle from '../components/MenuTitle.jsx'; 
import MenuCategories from '../components/MenuCategories.jsx'; 

const { items } = data;
const menuTitle = "Books Menu";
const tempAuthors = items.map((item) => item.volumeInfo.authors);

const tempSet = new Set(tempAuthors.flat());
const allAuthors = ["All", ...tempSet];

const BookList = () => {
  const [authors,  setAuthors] = useState(allAuthors);
  const [selectedAuthor, setSelectedAuthor] = useState("All");

  const filterAuthor = (author) => {
    setSelectedAuthor(author);
  };

  return (
    <section>
      <MenuTitle title={menuTitle} />
      <MenuCategories categories={authors} filterAuthor={filterAuthor} />

      <div className="book-list">
        {items.map((item) => {
          const { volumeInfo } = item;
          const { authors: bookAuthors, title, subtitle, imageLinks } = volumeInfo;

          if (selectedAuthor === "All" || (bookAuthors && bookAuthors.includes(selectedAuthor))) {
            return (
              <Book
                title={title}
                subtitle={subtitle}
                authors={bookAuthors}
                imageLinks={imageLinks}
                key={item.id}
              />
            );
          }
          return null; // If no match, return nothing
        })}
      </div>
    </section>
  );
};

export default BookList;
